get_bucket_policy(bucket, ...)
put_bucket_policy(bucket, policy, ...)
delete_bucket_policy(bucket, ...)s3HTTP.get_policy: A character string containing the JSON representation of the policy, if one has been set. For delete_policy and put_policy: TRUE if successful, FALSE otherwise. An aws_error object may be returned if the request failed.