get_policy(bucket, ...)
put_policy(bucket, ...)
delete_policy(bucket, ...)s3HTTP.get_policy: A list with a policy, if one has been set.. For delete_policy: TRUE if successful, FALSE otherwise. An aws_error object may be returned if the request failed.