Usage
s3curl(object, bucket, open = "rb", accelerate = FALSE, region = Sys.getenv("AWS_DEFAULT_REGION", "us-east-1"), key = Sys.getenv("AWS_ACCESS_KEY_ID"), secret = Sys.getenv("AWS_SECRET_ACCESS_KEY"))
Arguments
object
Character string with the object key, or an object of class s3_object. In most cases, if object is specified as the latter, bucket can be omitted because the bucket name will be extracted from Bucket slot in object.
bucket
Character string with the name of the bucket, or an object of class s3_bucket.
accelerate
A logical indicating whether to use AWS transfer acceleration, which can produce significant speed improvements for cross-country transfers. Acceleration only works with buckets that do not have dots in bucket name.
region
A character string containing the AWS region. Ignored if region can be inferred from bucket.
If missing, defaults to us-east-1.
key
A character string containing an AWS Access Key ID.
If missing, defaults to value stored in environment variable AWS_ACCESS_KEY_ID.
secret
A character string containing an AWS Secret Access Key.
If missing, defaults to value stored in environment variable AWS_SECRET_ACCESS_KEY.